netapp_ontap.models.dcn_node_software API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_node_software`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnNodeSoftwareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnNodeSoftware object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `compatibility: str GET POST PATCH`

    Indicates whether the node's software version is compatible with the ONTAP cluster. A node is considered compatible if its software release is not newer than the ONTAP cluster's release, and not more than four major versions older. This field helps determine if the node can join or be used to form the DCN cluster.

    Valid choices:

    - full
    - incompatible
  `version: DcnVersion GET`

    This contains DCN version information.